@@ -3,17 +3,6 @@ use strict;
 use warnings;
 use base 'Form::Processor::Field::Select';
 
-our $VERSION = '0.01';
-
-=head1 DESCRIPTION 
-
-This inherits from the Select field, which just provides options.
-and sets the "multiple" flag true to accept multiple options.
-If a field inherits from Select but you want to use it as a multiple
-select then just define the file as such.
-
-=cut
-
 
 sub init_multiple { 1 } # allow multiple values.
 
@@ -50,6 +39,55 @@ sub options {
     return wantarray ? @options : \@options;
 }
 
+
+=head1 NAME
+
+Form::Processor::Field::Multiple - Select one or more options
+
+=head1 SYNOPSIS
+
+See L<Form::Processor>
+
+=head1 DESCRIPTION
+
+This inherits from the Select field, which just provides options.
+and sets the "multiple" flag true to accept multiple options.
+If a field inherits from Select but you want to use it as a multiple
+select then just define the file as such.
+
+This also will arrange the currently selected items to the top of the list.
+
+=head2 Widget
+
+Fields can be given a widget type that is used as a hint for
+the code that renders the field.
+
+This field's widget type is: "select".
+
+=head2 Subclass
+
+Fields may inherit from other fields.  This field
+inherits from: "Select".
+
+=head1 AUTHORS
+
+Bill Moseley
+
+=head1 COPYRIGHT
+
+See L<Form::Processor> for copyright.
+
+This library is free software, you can redistribute it and/or modify it under
+the same terms as Perl itself.
+
+=head1 SUPPORT / WARRANTY
+
+L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
+Users are expected to review software for fitness and usability.
+
+=cut
+
+
 1;
 
 
